@@ -1,5 +1,4 @@
 import importlib.util
-import time
 from dataclasses import dataclass
 from typing import Optional
 
@@ -34,16 +33,14 @@ class DbHealthProvider(HealthProvider):
         return "db"
 
     def get_health(self) -> DbHealthStatus:
-        expected = int(time.time() * 1000)
         try:
-            res = self.engine.execute(f"SELECT {expected}")
-            actual = next(res)[0]
-            if expected == actual:
+            conn = self.engine.raw_connection()
+            if self.engine.dialect.do_ping(conn):
                 return DbHealthStatus(status=Status.UP, details=DbHealthDetails(self.engine.name))
 
             return DbHealthStatus(
                 status=Status.UNKNOWN,
-                details=DbHealthDetails(self.engine.name, f"Selected {expected}, got {actual}"))
+                details=DbHealthDetails(self.engine.name, f"Pinging failed"))
 
-        except OperationalError as e:
+        except Exception as e:  # pylint: disable=broad-except
             return DbHealthStatus(status=Status.DOWN, details=DbHealthDetails(self.engine.name, str(e)))
